import matplotlib.pyplot as plt
import pandas as pd
import numpy as np
from PIL import Image
from wordcloud import WordCloud, STOPWORDS
from twitterpersona.sentiment_analysis import count_tweets

def create_wordcloud(df):
    """
    Create a wordcloud out of all the tweets of a user. 
    Wordcloud colour is green if the overal sentiment of the
    users tweets is positive, red if negative and blue if 
    neutral.

    Parameters
    ----------
    df : pd.DataFrame
        dataframe with all the tweets of a user, and their
        sentiment analysis
    
    Returns
    -------
    plot : plt.figure()
        a matplotlib plot of the wordcloud
    
    Examples
    --------
    create_wordcloud(df)
    """

    # Import image to np.array
    mask = np.array(Image.open('twitterLogo.png'))
    
    # Combine all tweets into single string
    text = " ".join(tweet for tweet in df["text_clean"])

    # Determine tweet sentiment
    sentiment = count_tweets(df)

    # Set wordcloud colour
    if sentiment.idxmax() == 'positive':
        colormap = 'summer'
    elif sentiment.idxmax() == 'negative':
        colormap = 'autumn'
    else:
        colormap = 'cool'

    # Create the wordcloud
    wordcloud = WordCloud(
        width = 800, 
        height = 800, 
        min_font_size = 10, 
        stopwords = STOPWORDS,
        mask = mask,
        background_color = 'white',
        contour_color = '#00aced',
        contour_width = 8,
        colormap = colormap
    ).generate(text)
    fig = plt.figure(figsize = (8, 8), facecolor = None)
    plt.imshow(wordcloud)
    plt.axis("off")
    plt.tight_layout(pad = 0)
    plt.show()
    
    return fig



# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['twitterpersona']

package_data = \
{'': ['*']}

install_requires = \
['matplotlib>=3.6.3,<4.0.0',
 'nltk>=3.8.1,<4.0.0',
 'numpy>=1.24.1,<2.0.0',
 'pandas>=1.5.2,<2.0.0',
 'pillow>=9.4.0,<10.0.0',
 'python-dotenv>=0.21.0,<0.22.0',
 'tweepy>=4.12.1,<5.0.0',
 'tweet-preprocessor>=0.6.0,<0.7.0',
 'wordcloud>=1.8.2.2,<2.0.0.0']

setup_kwargs = {
    'name': 'twitterpersona',
    'version': '0.2.3',
    'description': "Assess whether a twitter is positive or negative based on the user's recent tweets",
    'long_description': '[![ci-cd](https://github.com/UBC-MDS/twitter-persona/actions/workflows/ci-cd.yml/badge.svg)](https://github.com/UBC-MDS/twitter-persona/actions/workflows/ci-cd.yml) [![Documentation Status](https://readthedocs.org/projects/twitterpersona/badge/?version=latest)](https://twitterpersona.readthedocs.io/en/latest/?badge=latest) ![PyPI](https://img.shields.io/pypi/v/twitterpersona) [![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT) \n# twitterpersona\n\nAssess a twitter user\'s character  based on their recent tweets\n\n## Summary\n\nTwitter is a popular social media app with over 1 billion user accounts. While a diversity of users is a strength, some individuals have concerns with the prevalence of "troll" accounts and individuals who exhibit unconstructive tone and diction whom they deem not worth engaging with.\nThe package twitterpersona is intended to provide insight into a twitter user based on their tweet history in effort to determine if an account is worth engaging with. The package provides an easy to use interface for determining the general sentiment expressed by a user.\n\n## Functions\n\n**load_twitter** : Returns a user\'s recent tweets (as a dataframe) given their `user id` using the Twitter API.\n\n**generalPreprocessing** : Cleans the recent tweet dataframe generated by `load_twitter`. Includes features such as removing punctuation and extracting emojis.\n\n**get_sentiment_result** : Determines the general (average) sentiment of recent tweets.\n\n**create_wordcloud** : Generates a word cloud of most frequently used words in tweets.\n\n## Scope and Fit\n\nThere are existing packages that preform tweet analysis (including [twitter-sentiment-analysis](https://github.com/abdulfatir/twitter-sentiment-analysis), [tweetlytics](https://github.com/UBC-MDS/tweetlytics), and [pytweet](https://github.com/UBC-MDS/pytweet)). However, none of these packages focus of providing metrics in the context of determining if the twitter user is worth engaging with.\n\n## Contributing\n\nInterested in contributing? Check out the contributing guidelines in CONTRIBUTING.md. Please note that this project is released with a Code of Conduct. By contributing to this project, you agree to abide by its terms.\n\n## License\n\n`twitterpersona` was created by Andy Wang, Renzo Wijngaarden, Roan Raina, Yurui Feng. It is licensed under the terms of the MIT license.\n\n## Credits\n\n`twitterpersona` was created with [`cookiecutter`](https://cookiecutter.readthedocs.io/en/latest/) and the `py-pkgs-cookiecutter` [template](https://github.com/py-pkgs/py-pkgs-cookiecutter).\n',
    'author': 'Andy Wang, Renzo Wijngaarden, Roan Raina, Yurui Feng',
    'author_email': 'None',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)



import pandas as pd
import tweepy
#from utils.auth import authHandler # adding utils function for auth

def user_info(consumer_key_input, consumer_secret_input, access_token_input, access_token_secret_input):

    user_info = {
    "consumer_key": consumer_key_input,
    "consumer_secret": consumer_secret_input,
    "access_token": access_token_input,
    "access_token_secret": access_token_secret_input
    }

    return user_info

def load_twitter_by_user(user, limit, user_info):
    """Load dataframe which contains specific user and return as a dataframe with total tweets.
    Parameters
    ----------
    user : str
        twitter user_name.

    limit : int
        how many tweets you wanna return.
    Returns
    -------
    dataframe
        dataframe contains username's twitter info.
    Examples
    --------
    load_twitter_by_user('Cristiano', 300)
    """

    consumer_key = user_info['consumer_key']
    consumer_secret = user_info['consumer_secret']
    access_token = user_info['access_token']
    access_token_secret = user_info['access_token_secret']
    
    auth = tweepy.OAuthHandler(consumer_key, consumer_secret)
    auth.set_access_token(access_token, access_token_secret)
    api = tweepy.API(auth)

    tweets = tweepy.Cursor(api.user_timeline, screen_name=user, count=200, tweet_mode='extended').items(limit)
    # create DataFrame
    columns = ['User', 'Id', "created_at","favorite_count","retweet_count", "text" ]
    data = []
    for tweet in tweets:
        data.append([tweet.user.screen_name, tweet.id_str, tweet.created_at, tweet.favorite_count, tweet.retweet_count, tweet.full_text.encode("utf-8").decode("utf-8")])
        df = pd.DataFrame(data, columns=columns)
    return df



def load_twitter_by_keywords(key, limit, user_info):
    """Load dataframe which contains specific user and return as a dataframe with total tweets.
    Parameters
    ----------
    key : str
        tweets keyword.

    limit : int
        how many tweets you wanna return.
    Returns
    -------
    dataframe
        dataframe contains username's twitter info.
    Examples
    --------
    load_twitter_by_keywords('2022', 100)
    """
    consumer_key = user_info['consumer_key']
    consumer_secret = user_info['consumer_secret']
    access_token = user_info['access_token']
    access_token_secret = user_info['access_token_secret']
    
    auth = tweepy.OAuthHandler(consumer_key, consumer_secret)
    auth.set_access_token(access_token, access_token_secret)
    
    api = tweepy.API(auth)
    tweets = tweepy.Cursor(api.search_tweets, q=key, count=100, tweet_mode='extended').items(limit)
    # create DataFrame
    columns = ['User', 'Id', "created_at","favorite_count","retweet_count", "text" ]
    data = []
    for tweet in tweets:
        data.append([tweet.user.screen_name, tweet.id_str, tweet.created_at, tweet.favorite_count, tweet.retweet_count, tweet.full_text.encode("utf-8").decode("utf-8")])
        df = pd.DataFrame(data, columns=columns)
    return df